@@ -1,4 +1,6 @@
 import Immutable from 'immutable'
+import { SET_CONSOLE_OPTIONS } from '../constants'
+import { actionReducer } from './utils'
 
 function setOptions ({ state, type, options }) {
   const optionsObj = {}
@@ -6,14 +8,14 @@ function setOptions ({ state, type, options }) {
   return state.mergeIn(['options'], optionsObj)
 }
 
-import { actionReducer } from './utils'
-
-const initialState = Immutable.fromJS({ options: {
-  consoleOptions: {},  // It contains vmId: { autoConnect: boolean }
-} })
+const initialState = Immutable.fromJS({
+  options: {
+    consoleOptions: {}, // It contains vmId: { autoConnect: boolean }
+  },
+})
 
 const options = actionReducer(initialState, {
-  SET_CONSOLE_OPTIONS (state, { payload: { vmId, options } }) {
+  [SET_CONSOLE_OPTIONS] (state, { payload: { vmId, options } }) {
     const optionsTemp = {}
     optionsTemp[vmId] = options
     return setOptions({ state, type: 'consoleOptions', options: optionsTemp })
@@ -21,3 +23,6 @@ const options = actionReducer(initialState, {
 })
 
 export default options
+export {
+  initialState,
+}
